<?php

namespace Drupal\search_api_decoupled_ui\Entity;

use Drupal\Core\Entity\EntityWithPluginCollectionInterface;
use Drupal\search_api_decoupled\Entity\SearchApiEndpoint as BaseSearchApiEndpoint;
use Drupal\search_api_decoupled_ui\SearchApiEndpointUiInterface;
use Drupal\search_api_decoupled_ui\SearchUiElementInterface;
use Drupal\search_api_decoupled_ui\SearchUiElementsPluginCollection;

/**
 * Defines overriden search api endpoint entity class with UI elements.
 */
class SearchApiEndpoint extends BaseSearchApiEndpoint implements SearchApiEndpointUiInterface, EntityWithPluginCollectionInterface {

  /**
   * The layout.
   *
   * @var string
   */
  protected $layout = 'search_onecol';

  /**
   * The array of ui elements for this search endpoint.
   *
   * @var array
   */
  protected $elements = [];

  /**
   * Holds the collection of search ui elements used by this search endpoint.
   *
   * @var \Drupal\search_api_decoupled_ui\SearchUiElementsPluginCollection
   */
  protected $elementsCollection;

  /**
   * Returns the ui elements plugin manager.
   *
   * @return \Drupal\Component\Plugin\PluginManagerInterface
   *   The ui elements plugin manager.
   */
  protected function getUiElementsPluginManager() {
    return \Drupal::service('plugin.manager.search_api_decoupled.ui_element_manager');
  }

  /**
   * {@inheritdoc}
   */
  public function getElement($element) {
    return $this->getElements()->get($element);
  }

  /**
   * {@inheritdoc}
   */
  public function getElements() {
    if (!$this->elementsCollection) {
      $this->elementsCollection = new SearchUiElementsPluginCollection($this->getUiElementsPluginManager(), $this->elements);
      $this->elementsCollection->sort();
    }
    return $this->elementsCollection;
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginCollections() {
    return ['elements' => $this->getElements()];
  }

  /**
   * {@inheritdoc}
   */
  public function addElement(array $configuration) {
    $configuration['uuid'] = $this->uuidGenerator()->generate();
    $configuration['search_api_endpoint'] = $this->id();
    $this->getElements()->addInstanceId($configuration['uuid'], $configuration);
    return $configuration['uuid'];
  }

  /**
   * {@inheritdoc}
   */
  public function deleteElement(SearchUiElementInterface $element) {
    $this->getElements()->removeInstanceId($element->getUuid());
    $this->save();
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getUiElementRegions() {
    $layout = \Drupal::service('plugin.manager.core.layout')->getDefinition($this->getLayout());
    $regions = [];
    foreach ($layout->getRegions() as $key => $region) {
      $regions[$key] = $region['label'];
    }
    return $regions;
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultUiElementRegion() {
    $layout = \Drupal::service('plugin.manager.core.layout')->getDefinition($this->getLayout());
    return $layout->getDefaultRegion();
  }

  /**
   * {@inheritdoc}
   */
  public function getLayout() {
    return $this->layout;
  }

}
