<?php

namespace Drupal\search_api_decoupled_ui\Plugin\search_ui_element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\search_api_decoupled_ui\ConfigurableSearchUiElementBase;

/**
 * Provide configuration for search result.
 *
 * @SearchUiElement(
 *   id = "search_result",
 *   label = @Translation("Rendered search result"),
 * )
 */
class SearchResult extends ConfigurableSearchUiElementBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'field' => '',
      'no_results' => $this->t('No results found.'),
      'loading' => $this->t('Loading...'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $search_api_endpoint = $form_state->get('search_api_endpoint');
    $index = $this->entityTypeManager->getStorage('search_api_index')->load($search_api_endpoint->getIndex());
    $options = ['' => $this->t('- Select -')];
    foreach ($index->getFields() as $field) {
      $options[$field->getFieldIdentifier()] = $field->getLabel();
    }
    $form['field'] = [
      '#type' => 'select',
      '#title' => $this->t('Field with rendered search result'),
      '#default_value' => $this->configuration['field'],
      '#required' => TRUE,
      '#options' => $options,
      '#weight' => 1,
    ];
    $form['no_results'] = [
      '#type' => 'textfield',
      '#title' => $this->t('No results message'),
      '#default_value' => $this->configuration['no_results'],
      '#weight' => 4,
    ];
    $form['loading'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Loading message'),
      '#default_value' => $this->configuration['loading'],
      '#weight' => 5,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['field'] = $form_state->getValue('field');
    $this->configuration['no_results'] = $form_state->getValue('no_results');
    $this->configuration['loading'] = $form_state->getValue('loading');
  }

  /**
   * {@inheritdoc}
   */
  public function getSummary() {
    return [
      '#markup' => $this->t('Field with HTML: @field.', ['@field' => $this->configuration['field']]),
    ];
  }

}
